==> pegasus-2.3.2.tar.bz2: pegasus-2.3.2/src/Pegasus/Provider/CMPI/CmpiBaseMI.h <==
//%2003////////////////////////////////////////////////////////////////////////
//
// Copyright (c) 2000, 2001, 2002  BMC Software, Hewlett-Packard Development
// Company, L. P., IBM Corp., The Open Group, Tivoli Systems.
// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L. P.;
// IBM Corp.; EMC Corporation, The Open Group.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
//==============================================================================
//
// Author:      Adrian Schuur, schuur@de.ibm.com
//
// Modified By: Heidi Neuman, heidineu@de.ibm.com
//              Angel Nunez Mencias, anunez@de.ibm.com
//              Viktor Mihajlovski, mihajlov@de.ibm.com
//
//%/////////////////////////////////////////////////////////////////////////////

#ifndef _CmpiBaseMI_h_
#define _CmpiBaseMI_h_

#include <iostream>

#include "cmpidt.h"
#include "cmpift.h"
#include "cmpimacs.h"

#include "CmpiProviderBase.h"
#include "Linkage.h"

class CmpiBroker;
class CmpiContext;
class CmpiStatus;

class PEGASUS_CMPI_PROVIDER_LINKAGE CmpiBaseMI {
public:
   virtual ~CmpiBaseMI();

   CmpiBaseMI(const CmpiBroker &mbp, const CmpiContext& ctx);

   void setProviderBase(CmpiProviderBase* base);
   CmpiProviderBase* getProviderBase();

   static CMPIStatus driveBaseCleanup(void* mi, CMPIContext* eCtx);

   virtual CmpiStatus initialize(const CmpiContext& ctx);
   virtual CmpiStatus cleanup(CmpiContext& ctx);
   virtual int isUnloadable() const;

protected:
   CmpiBroker* broker;
private:
   CmpiProviderBase* providerBase;
};

#endif

==> pegasus-2.5.tar.bz2: pegasus-2.5/src/Pegasus/Provider/CMPI/CmpiBaseMI.h <==
//%2005////////////////////////////////////////////////////////////////////////
//
// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
// IBM Corp.; EMC Corporation, The Open Group.
// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
// EMC Corporation; VERITAS Software Corporation; The Open Group.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
//==============================================================================
//
// Author:      Adrian Schuur, schuur@de.ibm.com
//
// Modified By: Heidi Neuman, heidineu@de.ibm.com
//              Angel Nunez Mencias, anunez@de.ibm.com
//              Viktor Mihajlovski, mihajlov@de.ibm.com
//
//%/////////////////////////////////////////////////////////////////////////////

#ifndef _CmpiBaseMI_h_
#define _CmpiBaseMI_h_

#include <iostream>

#include "cmpidt.h"
#include "cmpift.h"
#include "cmpimacs.h"

#include "CmpiProviderBase.h"
#include "Linkage.h"

class CmpiBroker;
class CmpiContext;
class CmpiStatus;

class PEGASUS_CMPI_PROVIDER_LINKAGE CmpiBaseMI {
public:
   virtual ~CmpiBaseMI();

   CmpiBaseMI(const CmpiBroker &mbp, const CmpiContext& ctx);

   void setProviderBase(CmpiProviderBase* base);
   CmpiProviderBase* getProviderBase();

   static CMPIStatus driveBaseCleanup(void* mi, const CMPIContext* eCtx, CMPIBoolean b);

   virtual CmpiStatus initialize(const CmpiContext& ctx);
   virtual CmpiStatus cleanup(CmpiContext& ctx);
   virtual int isUnloadable() const;

protected:
   CmpiBroker* broker;
private:
   CmpiProviderBase* providerBase;
};

#endif
